#
# spec file for package librdmacm
#
# Copyright (c) 2015 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define so_version 1
Name:           librdmacm
Version:        1.0.19.1
Release:        3.6
Summary:        RDMA cm library
License:        BSD-2-Clause or GPL-2.0
Group:          Productivity/Networking/Other
Url:            http://www.openfabrics.org
Source0:        https://www.openfabrics.org/downloads/rdmacm/%{name}-%{version}.tar.gz
Source99:       baselibs.conf
Patch0:         librdmacm-need_pthread.patch
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  libibverbs-devel
BuildRequires:  libtool
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
RDMA cm library

%package -n     librdmacm%{so_version}
Summary:        RDMA cm runtime library
Group:          System/Libraries
Obsoletes:      librdmacm < %{version}
Provides:       librdmacm = %{version}

%description -n librdmacm%{so_version}
This package contains the RGM cm runtime library.

%package        devel
Summary:        Development files for the librdmacm library
Group:          Development/Libraries/C and C++
Requires:       %{name}%{so_version} = %{version}
Requires:       libibverbs-devel

%description devel
Development files for the librdmacm library.

%package        tools
Summary:        Tools and example programs using the RDMA cm library
Group:          Productivity/Networking/Other

%description    tools
Tools and example programs that use the RDMA cm library.

%prep
%setup -q
%patch0
# These files are empty and configure tells automake these are
# foreign sources.
rm -f ChangeLog NEWS INSTALL

%build
autoreconf -fvi
%configure \
    --with-pic \
    --disable-silent-rules \
    --disable-static
make %{?_smp_mflags}

%install
make DESTDIR=%{buildroot} install %{?_smp_mflags}
find %{buildroot} -type f -name "*.la" -delete -print

%post -n %{name}%{so_version} -p /sbin/ldconfig

%postun -n %{name}%{so_version} -p /sbin/ldconfig

%files tools
%defattr(-, root, root)
%dir %{_libdir}/rsocket
%{_bindir}/*
%{_mandir}/man1/*
%{_mandir}/man7/*

%files -n %{name}%{so_version}
%defattr(-, root, root)
%doc COPYING
%{_libdir}/librdmacm.so.*
%{_libdir}/rsocket/librspreload.so.*

%files devel
%defattr(-,root,root)
%{_includedir}/rdma
%{_includedir}/infiniband/ib.h
%{_libdir}/librdmacm.so
%{_libdir}/rsocket/librspreload.so
%{_mandir}/man3/*

%changelog
* Mon Feb 16 2015 tchvatal@suse.com
- clean up with spec-cleaner
* Thu Feb 12 2015 p.drouand@gmail.com
- Update to version 1.0.19.1
  * No changelog available
* Thu Jun 26 2014 pth@suse.de
- Add baselibs.conf as source.
- Don't package static library.
* Wed Jun 25 2014 pth@suse.de
- Fix source URL.
* Thu Jun 12 2014 pth@suse.de
- Remove librdmacm-configure.patch as it's not needed anymore.
* Fri Jun  6 2014 pth@suse.de
- Add obsoletes/provides as the package was split and the package
  containing the shared library renamed to conform with our
  shared library policy (bnc#881534).
* Tue Jun  3 2014 pth@suse.de
- Update to OFED 3.12 final.
* Mon Jun  2 2014 pth@suse.de
- Update to 1.0.18.1 from OFED 3.12, no log of changes present.
* Thu Feb 13 2014 pth@suse.de
- Update to 1.0.18 for fate#315488, no changelog.
* Tue Feb 11 2014 pth@suse.de
- Change License to BSD-2-Clause or GPL-2.0
- Include COPYING as documentation of the runtime lib package.
- Fix baselibs.conf
* Fri Jan 17 2014 pth@suse.de
- Update to 1.0.17 from OFED 3.12 daily
- Enable build for s390x.
- Use spdx.org format for license specification.
* Tue Sep 11 2012 pth@suse.de
- Update to 1.0.15 from OFED 1.5.4.1.
* Tue Sep 11 2012 jengelh@inai.de
- Remove redundant sections from specfile
- Parallel build with %%_smp_mflags
* Thu Jun 28 2012 pth@suse.de
- Split off runtime library into its own sub package.
- Put tools and example programs into a -tools package.
* Tue May  8 2012 pth@suse.de
- BuildRequire automake, autoconf and libtool.
* Mon Oct 25 2010 jjolly@novell.com
- Added infiniband/ib.h to %%files
* Mon Oct 25 2010 jjolly@novell.com
- Update to 1.0.13 from OFED 1.5.2
- Removed cma patch
* Wed Jan  7 2009 olh@suse.de
- obsolete old -XXbit packages (bnc#437293)
* Wed Dec 10 2008 jjolly@suse.de
- Updated to package from OFED 1.4 GA
  - version update
* Thu Nov  6 2008 ihno@suse.de
- adding baselibs.conf
- adding ExcludeArch s390 s390x
* Fri Oct 24 2008 jjolly@suse.de
- Updated to version from the OFED 1.4 RC3
* Wed Oct 15 2008 jjolly@suse.de
- Patched to fix segfault on QS22 hardware (bnc#426594)
* Tue Sep  9 2008 jjolly@suse.de
- Updated to 1.0.8 from the OFED 1.4 RC1
* Mon Apr 28 2008 crrodriguez@suse.de
- update to version 1.0.7 , no upstream changelog available
* Tue Mar  4 2008 jjolly@suse.de
- Updated to 1.0.6 from the OFED 1.3 GA release
* Wed Nov 28 2007 crrodriguez@suse.de
- Update to 1.0.4 for OFED 1.3, there is no changelog available
* Tue Aug  7 2007 hvogel@suse.de
- Update to 1.0.2 from OFED 1.2c
* Mon Jul  9 2007 hvogel@suse.de
- Use correct version number
* Mon Jul  2 2007 hvogel@suse.de
- Update to OFED 1.2 release
* Wed Jun 20 2007 hvogel@suse.de
- Initial Package, Version 1.0.2
